@@ -20,11 +20,11 @@ import (
 	pcmd "github.com/confluentinc/cli/internal/pkg/cmd"
 	v1 "github.com/confluentinc/cli/internal/pkg/config/v1"
 	"github.com/confluentinc/cli/internal/pkg/errors"
+	"github.com/confluentinc/cli/internal/pkg/examples"
 	"github.com/confluentinc/cli/internal/pkg/kafkarest"
 	"github.com/confluentinc/cli/internal/pkg/log"
 	"github.com/confluentinc/cli/internal/pkg/output"
 	"github.com/confluentinc/cli/internal/pkg/serdes"
-	"github.com/confluentinc/cli/internal/pkg/types"
 )
 
 type command struct {
@@ -65,6 +65,12 @@ func newExportCommand(prerunner pcmd.PreRunner) *cobra.Command {
 		Short: "Export an AsyncAPI specification.",
 		Long:  "Export an AsyncAPI specification for a Kafka cluster and Schema Registry.",
 		Args:  cobra.NoArgs,
+		Example: examples.BuildExampleString(
+			examples.Example{
+				Text: `Export an AsyncAPI specification with topic "my-topic" and all topics starting with "prefix-".`,
+				Code: `confluent asyncapi export --topics "my-topic,prefix-*"`,
+			},
+		),
 	}
 
 	c := &command{pcmd.NewAuthenticatedCLICommand(cmd, prerunner)}
@@ -78,7 +84,7 @@ func newExportCommand(prerunner pcmd.PreRunner) *cobra.Command {
 	cmd.Flags().String("schema-registry-api-key", "", "API key for Schema Registry.")
 	cmd.Flags().String("schema-registry-api-secret", "", "API secret for Schema Registry.")
 	cmd.Flags().String("schema-context", "default", "Use a specific schema context.")
-	cmd.Flags().StringSlice("topics", nil, "A comma-separated list of topics to export.")
+	cmd.Flags().StringSlice("topics", nil, "A comma-separated list of topics to export. Supports prefixes ending with a wildcard (*).")
 	pcmd.AddValueFormatFlag(cmd)
 	pcmd.AddClusterFlag(cmd, c.AuthenticatedCLICommand)
 	pcmd.AddEnvironmentFlag(cmd, c.AuthenticatedCLICommand)
@@ -108,39 +114,37 @@ func (c *command) export(cmd *cobra.Command, _ []string) error {
 	}
 	channelCount := 0
 
-	topicsSpecified := types.NewSet(flags.topics...)
 	for _, topic := range accountDetails.topics {
-		// Only use user-specified topics if parameter passed
-		if len(topicsSpecified) > 0 && !topicsSpecified.Contains(topic.GetTopicName()) {
+		if !topicMatch(topic.GetTopicName(), flags.topics) {
 			continue
 		}
+
 		for _, subject := range accountDetails.subjects {
-			if subject != schemaContextPrefix+topic.GetTopicName()+"-value" || strings.HasPrefix(topic.GetTopicName(), "_") {
+			if subject != fmt.Sprintf("%s%s-value", schemaContextPrefix, topic.GetTopicName()) || strings.HasPrefix(topic.GetTopicName(), "_") {
 				// Avoid internal topics or if subject does not follow topic naming strategy
 				continue
-			} else {
-				// Subject and Topic matches
-				// Reset channel details
-				accountDetails.channelDetails = channelDetails{
-					currentTopic:   topic,
-					currentSubject: subject,
-				}
-				err := c.getChannelDetails(accountDetails, flags)
-				if err != nil {
-					if err.Error() == protobufErrorMessage {
-						log.CliLogger.Info(err.Error())
-						continue
-					}
-					return err
-				}
-				channelCount++
-				messages[msgName(topic.GetTopicName())] = spec.Message{
-					OneOf1: &spec.MessageOneOf1{MessageEntity: accountDetails.buildMessageEntity()},
-				}
-				reflector, err = addChannel(reflector, accountDetails.channelDetails)
-				if err != nil {
-					return err
+			}
+			// Subject and Topic matches
+			// Reset channel details
+			accountDetails.channelDetails = channelDetails{
+				currentTopic:   topic,
+				currentSubject: subject,
+			}
+			err := c.getChannelDetails(accountDetails, flags)
+			if err != nil {
+				if err.Error() == protobufErrorMessage {
+					log.CliLogger.Info(err.Error())
+					continue
 				}
+				return err
+			}
+			channelCount++
+			messages[msgName(topic.GetTopicName())] = spec.Message{
+				OneOf1: &spec.MessageOneOf1{MessageEntity: accountDetails.buildMessageEntity()},
+			}
+			reflector, err = addChannel(reflector, accountDetails.channelDetails)
+			if err != nil {
+				return err
 			}
 		}
 	}
@@ -575,3 +579,17 @@ func createConsumer(broker string, clusterCreds *v1.APIKeyPair, groupId string)
 	}
 	return consumer, nil
 }
+
+// Check if topic matches user-specified topics/prefixes. True if user didn't specify
+func topicMatch(topic string, userTopics []string) bool {
+	if len(userTopics) == 0 {
+		return true
+	}
+
+	for _, userTopic := range userTopics {
+		if strings.HasSuffix(userTopic, "*") && strings.HasPrefix(topic, strings.TrimSuffix(userTopic, "*")) || userTopic == topic {
+			return true
+		}
+	}
+	return false
+}
