@@ -27,11 +27,10 @@ func (c *command) list(cmd *cobra.Command, _ []string) error {
 		return err
 	}
 
-	environmentId, _ := c.EnvironmentId()
 	list := output.NewList(cmd)
 	for _, environment := range environments {
 		list.Add(&out{
-			IsCurrent: environment.GetId() == environmentId,
+			IsCurrent: environment.GetId() == c.Context.GetCurrentEnvironment(),
 			Id:        environment.GetId(),
 			Name:      environment.GetDisplayName(),
 		})
