@@ -59,6 +59,10 @@ func (c *roleCommand) ccloudDescribe(cmd *cobra.Command, role string) error {
 		namespacesList = append(namespacesList, identityNamespace.Value())
 	}
 
+	if featureflags.Manager.BoolVariation("flink.rbac.namespace.cli.enable", c.Context, ldClient, true, false) {
+		namespacesList = append(namespacesList, flinkNamespace.Value())
+	}
+
 	namespaces := optional.NewString(strings.Join(namespacesList, ","))
 
 	opts := &mdsv2alpha1.RoleDetailOpts{Namespace: namespaces}
