@@ -77,9 +77,9 @@ type Config struct {
 	NoBrowser           bool                        `json:"no_browser"`
 	Platforms           map[string]*Platform        `json:"platforms,omitempty"`
 	Credentials         map[string]*Credential      `json:"credentials,omitempty"`
+	CurrentContext      string                      `json:"current_context"`
 	Contexts            map[string]*Context         `json:"contexts,omitempty"`
 	ContextStates       map[string]*ContextState    `json:"context_states,omitempty"`
-	CurrentContext      string                      `json:"current_context"`
 	AnonymousId         string                      `json:"anonymous_id,omitempty"`
 	SavedCredentials    map[string]*LoginCredential `json:"saved_credentials,omitempty"`
 
@@ -88,9 +88,10 @@ type Config struct {
 	IsTest  bool              `json:"-"`
 	Version *pversion.Version `json:"-"`
 
-	overwrittenCurrentContext      string
-	overwrittenCurrentEnvironment  string
-	overwrittenCurrentKafkaCluster string
+	overwrittenCurrentContext          string
+	overwrittenCurrentEnvironment      string
+	overwrittenCurrentFlinkComputePool string
+	overwrittenCurrentKafkaCluster     string
 }
 
 func (c *Config) SetOverwrittenCurrentContext(context string) {
@@ -108,6 +109,12 @@ func (c *Config) SetOverwrittenCurrentEnvironment(environmentId string) {
 	}
 }
 
+func (c *Config) SetOverwrittenFlinkComputePool(computePoolId string) {
+	if c.overwrittenCurrentFlinkComputePool == "" {
+		c.overwrittenCurrentFlinkComputePool = computePoolId
+	}
+}
+
 func (c *Config) SetOverwrittenCurrentKafkaCluster(clusterId string) {
 	if clusterId == "" {
 		clusterId = emptyFieldIndicator
